@@ -34,6 +34,7 @@
 #include <libxml/tree.h>
 #include <libxml/xpath.h>
 #include <libxml/xmlreader.h>
+#include "ignore-value.h"
 #include "osinfo_install_script_private.h"
 #include "osinfo_device_driver_private.h"
 
@@ -84,9 +85,7 @@ osinfo_loader_class_init (OsinfoLoaderClass *klass)
 static void
 osinfo_loader_init (OsinfoLoader *loader)
 {
-    OsinfoLoaderPrivate *priv;
-    loader->priv = priv = OSINFO_LOADER_GET_PRIVATE(loader);
-
+    loader->priv = OSINFO_LOADER_GET_PRIVATE(loader);
     loader->priv->db = osinfo_db_new();
 }
 
@@ -1488,20 +1487,15 @@ osinfo_loader_process_file_reg_ids(OsinfoLoader *loader,
                 WANT_ID(subvendor_id);
                 WANT_ID(subdevice_id);
                 WANT_REST(subsystem);
-
-                /* Pretend we 'use' these variables to get around
-                 * 'gcc' warnings about set-but-not-read vars */
-                if (subvendor_id || subdevice_id || subsystem)
-                    subsystem = subsystem;
+                ignore_value(subvendor_id);
+                ignore_value(subdevice_id);
+                ignore_value(subsystem);
             } else {
                 FREE_BUF(device_buf);
                 WANT_ID(device_id);
                 WANT_REST(device);
                 SAVE_BUF(device_buf);
-
-                /* Trick gcc set-by-not-read-vars warning */
-                if (device)
-                    device = device;
+                ignore_value(device);
 
                 gchar *id = g_strdup_printf("%s/%s/%s",
                                             baseURI, vendor_id, device_id);
@@ -1523,10 +1517,7 @@ osinfo_loader_process_file_reg_ids(OsinfoLoader *loader,
             WANT_ID(vendor_id);
             WANT_REST(vendor);
             SAVE_BUF(vendor_buf);
-
-            /* Trick gcc set-by-not-read-vars warning */
-            if (vendor)
-                vendor = vendor;
+            ignore_value(vendor);
         }
 
     done:
